nautobot.apps.config - Nautobot Documentation

Skip to content

# `nautobot.apps.config`

Helper code for loading values that may be defined in settings.py/nautobot_config.py or in django-constance.

## `nautobot.apps.config.get_app_settings_or_config(app_name, variable_name, fallback=None)`

Get a value from Django settings.PLUGINS_CONFIG (if specified there) or Constance configuration (otherwise).

The fallback value is returned only if the requested variable cannot be found at all - this is an error case, and will generate warning logs.